/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

@charset "UTF-8";
.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-element table td.fr-selected-cell, .fr-element table th.fr-selected-cell {
  border: 1px double #0098f7;
  position: relative;
  /**
  Removed the ::after, as it blocks the browser’s ability to correctly place the caret (text cursor) mainly in firefox.
  provided the background color directly to the selected cell.
  */
  background-color: rgba(0, 100, 255, 0.15); }
.fr-element table td, .fr-element table th {
  user-select: text;
  -o-user-select: text;
  -moz-user-select: text;
  -khtml-user-select: text;
  -webkit-user-select: text;
  -ms-user-select: text; }
.fr-element .fr-no-selection table td, .fr-element .fr-no-selection table th {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none; }

.fr-table-resizer {
  position: absolute;
  z-index: 3;
  display: none; }
  .fr-table-resizer.fr-table-col-resizer {
    cursor: col-resize; }
    .fr-table-resizer.fr-table-col-resizer div {
      -webkit-opacity: 0;
      -moz-opacity: 0;
      opacity: 0;
      -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
      border-right: 1px solid #0098f7; }
  .fr-table-resizer.fr-table-row-resizer {
    cursor: row-resize; }
    .fr-table-resizer.fr-table-row-resizer div {
      -webkit-opacity: 0;
      -moz-opacity: 0;
      opacity: 0;
      -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
      border-bottom: 1px solid #0098f7; }
  .fr-table-resizer.fr-moving {
    z-index: 2; }

.fr-no-selection {
  user-select: none;
  -o-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none; }

.fr-popup .fr-table-size {
  margin: 20px; }
  .fr-popup .fr-table-size .fr-table-size-info {
    text-align: center;
    font-size: 14px; }
  .fr-popup .fr-table-size .fr-select-table-size {
    line-height: 0;
    padding: 5px;
    white-space: nowrap; }
    .fr-popup .fr-table-size .fr-select-table-size > span {
      display: inline-block;
      padding: 0 4px 4px 0;
      background: transparent; }
      .fr-popup .fr-table-size .fr-select-table-size > span > span {
        display: inline-block;
        width: 18px;
        height: 18px;
        border: 1px solid #DDD; }
      .fr-popup .fr-table-size .fr-select-table-size > span.hover {
        background: transparent; }
        .fr-popup .fr-table-size .fr-select-table-size > span.hover > span {
          background: rgba(0, 152, 247, 0.3);
          border: solid 1px #0098f7; }
    .fr-popup .fr-table-size .fr-select-table-size .new-line::after {
      clear: both;
      display: block;
      content: "";
      height: 0; }
.fr-popup.fr-above .fr-table-size .fr-select-table-size > span {
  display: inline-block !important; }
.fr-popup .fr-table-colors {
  display: block;
  padding: 20px;
  padding-bottom: 0; }

.fr-popup.fr-desktop .fr-table-size .fr-select-table-size > span > span {
  width: 12px;
  height: 12px; }

.fr-insert-helper {
  position: absolute;
  z-index: 9999;
  white-space: nowrap; }

.fr-cell-properties-form, .fr-table-properties-form {
  padding: 15px;
  width: 360px;
  max-width: 100%;
  background-color: #FFF;
  border-radius: 10px; }
  .fr-cell-properties-form .fr-cell-properties-section, .fr-cell-properties-form .fr-table-properties-section, .fr-table-properties-form .fr-cell-properties-section, .fr-table-properties-form .fr-table-properties-section {
    margin-bottom: 12px; }
    .fr-cell-properties-form .fr-cell-properties-section label, .fr-cell-properties-form .fr-table-properties-section label, .fr-table-properties-form .fr-cell-properties-section label, .fr-table-properties-form .fr-table-properties-section label {
      font-weight: bold;
      display: block;
      margin-bottom: 6px;
      font-size: 14px; }
  .fr-cell-properties-form .fr-cell-bg-container, .fr-cell-properties-form .fr-table-bg-container, .fr-table-properties-form .fr-cell-bg-container, .fr-table-properties-form .fr-table-bg-container {
    display: flex;
    align-items: center;
    position: relative;
    width: 100%; }
    .fr-cell-properties-form .fr-cell-bg-container .fr-input, .fr-cell-properties-form .fr-table-bg-container .fr-input, .fr-table-properties-form .fr-cell-bg-container .fr-input, .fr-table-properties-form .fr-table-bg-container .fr-input {
      flex: 1;
      height: 36px;
      padding: 4px 12px;
      border: 1px solid #CCCCCC;
      border-radius: 2px 0 0 2px;
      box-sizing: border-box;
      font-size: 14px; }
      .fr-cell-properties-form .fr-cell-bg-container .fr-input:focus, .fr-cell-properties-form .fr-table-bg-container .fr-input:focus, .fr-table-properties-form .fr-cell-bg-container .fr-input:focus, .fr-table-properties-form .fr-table-bg-container .fr-input:focus {
        outline: none;
        border-color: #0098f7; }
      .fr-cell-properties-form .fr-cell-bg-container .fr-input.fr-disabled, .fr-cell-properties-form .fr-table-bg-container .fr-input.fr-disabled, .fr-table-properties-form .fr-cell-bg-container .fr-input.fr-disabled, .fr-table-properties-form .fr-table-bg-container .fr-input.fr-disabled {
        background-color: #f5f5f5;
        color: #a9a9a9;
        border: 1px solid #d1d1d1;
        cursor: not-allowed; }
      .fr-cell-properties-form .fr-cell-bg-container .fr-input::placeholder, .fr-cell-properties-form .fr-table-bg-container .fr-input::placeholder, .fr-table-properties-form .fr-cell-bg-container .fr-input::placeholder, .fr-table-properties-form .fr-table-bg-container .fr-input::placeholder {
        color: #AAA; }
    .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color {
      width: 36px;
      height: 36px;
      border: 1px solid #CCCCCC;
      border-left: none;
      border-radius: 0 2px 2px 0;
      position: relative;
      padding: 0;
      background: transparent;
      height: 36px;
      display: flex;
      align-items: center;
      justify-content: center;
      cursor: pointer;
      margin: -1px 0 0 -1px; }
      .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color:hover, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color:hover, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color:hover, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color:hover, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color:hover, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color:hover, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color:hover, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color:hover, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color:hover, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color:hover, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color:hover, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color:hover {
        background-color: #ebebeb; }
      .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview {
        width: 20px;
        height: 20px;
        border: 1px solid #999999;
        border-radius: 2px;
        position: relative;
        overflow: hidden; }
        .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-cell-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-cell-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-cell-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-bg-color .fr-table-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-color-preview .fr-table-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-color-preview-indicator, .fr-table-properties-form .fr-table-bg-container .fr-btn-table-border-bg-color .fr-table-color-preview .fr-table-color-preview-indicator {
          position: absolute;
          background: red;
          width: 28px;
          height: 1px;
          top: 9px;
          left: -4px;
          transform: rotate(-45deg);
          transform-origin: center; }
  .fr-cell-properties-form .fr-cell-dimensions-container, .fr-table-properties-form .fr-cell-dimensions-container {
    display: flex;
    gap: 10px;
    margin-bottom: 12px; }
    .fr-cell-properties-form .fr-cell-dimensions-container label, .fr-table-properties-form .fr-cell-dimensions-container label {
      font-weight: bold;
      font-size: 14px; }
    .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section {
      flex: 1; }
      .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs {
        display: flex;
        gap: 6px;
        align-items: center; }
        .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input {
          width: 90px;
          padding: 8px;
          border: 1px solid #CCCCCC;
          border-radius: 2px;
          font-size: 14px; }
          .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input:focus, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input:focus {
            outline: none;
            border-color: #0098f7; }
          .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input.fr-disabled, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input.fr-disabled {
            background-color: #f5f5f5;
            color: #a9a9a9;
            border: 1px solid #d1d1d1;
            cursor: not-allowed; }
          .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input::placeholder, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs input::placeholder {
            color: #AAA; }
        .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs .fr-dimension-separator, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-dimension-section .fr-dimension-inputs .fr-dimension-separator {
          line-height: 1;
          font-size: 16px; }
    .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section {
      flex: 1; }
      .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section label, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section label {
        font-weight: bold;
        font-size: 14px; }
      .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input {
        width: 90px;
        padding: 8px;
        border: 1px solid #CCCCCC;
        border-radius: 2px;
        font-size: 14px; }
        .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input:focus, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input:focus {
          outline: none;
          border-color: #0098f7; }
        .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input.fr-disabled, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input.fr-disabled {
          background-color: #f5f5f5;
          color: #a9a9a9;
          border: 1px solid #d1d1d1;
          cursor: not-allowed; }
        .fr-cell-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input::placeholder, .fr-table-properties-form .fr-cell-dimensions-container .fr-cell-padding-section input::placeholder {
          color: #AAA; }
  .fr-cell-properties-form .fr-cell-properties-buttons, .fr-cell-properties-form .fr-table-properties-buttons, .fr-table-properties-form .fr-cell-properties-buttons, .fr-table-properties-form .fr-table-properties-buttons {
    display: flex;
    justify-content: flex-end;
    gap: 10px;
    margin-top: 20px; }
    .fr-cell-properties-form .fr-cell-properties-buttons .fr-cancel-button, .fr-cell-properties-form .fr-cell-properties-buttons .fr-save-button, .fr-cell-properties-form .fr-table-properties-buttons .fr-cancel-button, .fr-cell-properties-form .fr-table-properties-buttons .fr-save-button, .fr-table-properties-form .fr-cell-properties-buttons .fr-cancel-button, .fr-table-properties-form .fr-cell-properties-buttons .fr-save-button, .fr-table-properties-form .fr-table-properties-buttons .fr-cancel-button, .fr-table-properties-form .fr-table-properties-buttons .fr-save-button {
      font-size: 14px;
      cursor: pointer;
      padding: 8px 12px;
      font-weight: 500;
      height: 36px;
      line-height: 20px;
      box-sizing: border-box; }
      .fr-cell-properties-form .fr-cell-properties-buttons .fr-cancel-button.fr-disabled, .fr-cell-properties-form .fr-cell-properties-buttons .fr-save-button.fr-disabled, .fr-cell-properties-form .fr-table-properties-buttons .fr-cancel-button.fr-disabled, .fr-cell-properties-form .fr-table-properties-buttons .fr-save-button.fr-disabled, .fr-table-properties-form .fr-cell-properties-buttons .fr-cancel-button.fr-disabled, .fr-table-properties-form .fr-cell-properties-buttons .fr-save-button.fr-disabled, .fr-table-properties-form .fr-table-properties-buttons .fr-cancel-button.fr-disabled, .fr-table-properties-form .fr-table-properties-buttons .fr-save-button.fr-disabled {
        pointer-events: none;
        cursor: not-allowed;
        color: #a9a9a9; }
    .fr-cell-properties-form .fr-cell-properties-buttons .fr-cancel-button, .fr-cell-properties-form .fr-table-properties-buttons .fr-cancel-button, .fr-table-properties-form .fr-cell-properties-buttons .fr-cancel-button, .fr-table-properties-form .fr-table-properties-buttons .fr-cancel-button {
      background: none;
      border: none;
      color: #0098f7;
      border-radius: 2px; }
      .fr-cell-properties-form .fr-cell-properties-buttons .fr-cancel-button:hover, .fr-cell-properties-form .fr-table-properties-buttons .fr-cancel-button:hover, .fr-table-properties-form .fr-cell-properties-buttons .fr-cancel-button:hover, .fr-table-properties-form .fr-table-properties-buttons .fr-cancel-button:hover {
        text-decoration: underline; }
    .fr-cell-properties-form .fr-cell-properties-buttons .fr-save-button, .fr-cell-properties-form .fr-table-properties-buttons .fr-save-button, .fr-table-properties-form .fr-cell-properties-buttons .fr-save-button, .fr-table-properties-form .fr-table-properties-buttons .fr-save-button {
      background-color: #FFF;
      border: 1px solid #0098f7;
      color: #0098f7;
      border-radius: 2px; }
      .fr-cell-properties-form .fr-cell-properties-buttons .fr-save-button:hover, .fr-cell-properties-form .fr-table-properties-buttons .fr-save-button:hover, .fr-table-properties-form .fr-cell-properties-buttons .fr-save-button:hover, .fr-table-properties-form .fr-table-properties-buttons .fr-save-button:hover {
        background-color: #ebebeb; }
  .fr-cell-properties-form .fr-error, .fr-table-properties-form .fr-error {
    color: red;
    font-size: 12px;
    padding-bottom: 5px;
    display: none; }
  .fr-cell-properties-form input.fr-error, .fr-table-properties-form input.fr-error {
    border-color: red;
    display: block; }

.fr-table-properties-section label:not(:first-child) {
  margin-top: 15px; }
.fr-table-properties-section .fr-command.fr-btn + .fr-dropdown-menu .fr-dropdown-wrapper .fr-dropdown-content ul.fr-dropdown-list li a {
  line-height: 170%; }

.fr-table-bg-container .fr-input-line, .fr-table-border-container .fr-input-line, .fr-table-dimensions-container .fr-input-line, .fr-table-style-container .fr-input-line {
  padding: 0px;
  width: 100%; }
  .fr-table-bg-container .fr-input-line input[type="text"], .fr-table-border-container .fr-input-line input[type="text"], .fr-table-dimensions-container .fr-input-line input[type="text"], .fr-table-style-container .fr-input-line input[type="text"] {
    height: 36px;
    border-color: #CCCCCC; }
  .fr-table-bg-container .fr-input-line input + label, .fr-table-border-container .fr-input-line input + label, .fr-table-dimensions-container .fr-input-line input + label, .fr-table-style-container .fr-input-line input + label {
    top: -5px;
    font-weight: 100; }
  .fr-table-bg-container .fr-input-line input.fr-not-empty + label, .fr-table-border-container .fr-input-line input.fr-not-empty + label, .fr-table-dimensions-container .fr-input-line input.fr-not-empty + label, .fr-table-style-container .fr-input-line input.fr-not-empty + label {
    top: -20px;
    font-weight: 100; }
  .fr-table-bg-container .fr-input-line #fr-table-border-style, .fr-table-border-container .fr-input-line #fr-table-border-style, .fr-table-dimensions-container .fr-input-line #fr-table-border-style, .fr-table-style-container .fr-input-line #fr-table-border-style {
    width: 90%;
    height: 36px;
    border-color: #CCCCCC;
    border-radius: 2px; }
  .fr-table-bg-container .fr-input-line .fr-field-lable, .fr-table-border-container .fr-input-line .fr-field-lable, .fr-table-dimensions-container .fr-input-line .fr-field-lable, .fr-table-style-container .fr-input-line .fr-field-lable {
    position: absolute;
    font-size: 11px;
    padding: 0px 3px;
    margin: -6px 5px;
    background: #FFF;
    font-weight: 100;
    color: dimgray;
    z-index: 3; }
  .fr-table-bg-container .fr-input-line .fr-buttons, .fr-table-border-container .fr-input-line .fr-buttons, .fr-table-dimensions-container .fr-input-line .fr-buttons, .fr-table-style-container .fr-input-line .fr-buttons {
    padding: 0px; }
  .fr-table-bg-container .fr-input-line .fr-command.fr-btn.fr-dropdown:after, .fr-table-border-container .fr-input-line .fr-command.fr-btn.fr-dropdown:after, .fr-table-dimensions-container .fr-input-line .fr-command.fr-btn.fr-dropdown:after, .fr-table-style-container .fr-input-line .fr-command.fr-btn.fr-dropdown:after {
    right: 10px; }
  .fr-table-bg-container .fr-input-line .fr-command.fr-btn.fr-dropdown.fr-active, .fr-table-border-container .fr-input-line .fr-command.fr-btn.fr-dropdown.fr-active, .fr-table-dimensions-container .fr-input-line .fr-command.fr-btn.fr-dropdown.fr-active, .fr-table-style-container .fr-input-line .fr-command.fr-btn.fr-dropdown.fr-active {
    background: transparent; }
  .fr-table-bg-container .fr-input-line .fr-dropdown, .fr-table-border-container .fr-input-line .fr-dropdown, .fr-table-dimensions-container .fr-input-line .fr-dropdown, .fr-table-style-container .fr-input-line .fr-dropdown {
    margin: 0px;
    background: transparent;
    border: 1px solid #CCCCCC;
    margin-right: 10px;
    height: 36px;
    border-radius: 2px; }

.fr-table-border-container .fr-dropdown-wrapper {
  width: 120px; }

.fr-table-alignment-section {
  margin-left: 10px; }

.fr-table-border-container, .fr-table-dimensions-container, .fr-table-dimensions-section {
  display: flex;
  margin-top: 10px; }
  .fr-table-border-container .fr-dimension-separator, .fr-table-dimensions-container .fr-dimension-separator, .fr-table-dimensions-section .fr-dimension-separator {
    margin: 10px 5px; }
  .fr-table-border-container .fr-btn-table-border-bg-color, .fr-table-dimensions-container .fr-btn-table-border-bg-color, .fr-table-dimensions-section .fr-btn-table-border-bg-color {
    margin-right: 10px;
    background: transparent;
    border: 1px solid #CCCCCC;
    border-radius: 2px;
    border-left: 0px;
    height: 36px;
    margin-left: -1px; }
    .fr-table-border-container .fr-btn-table-border-bg-color .fr-border-color-preview, .fr-table-dimensions-container .fr-btn-table-border-bg-color .fr-border-color-preview, .fr-table-dimensions-section .fr-btn-table-border-bg-color .fr-border-color-preview {
      width: 20px;
      height: 20px;
      border: 1px solid #999999;
      border-radius: 2px;
      position: relative;
      overflow: hidden; }
      .fr-table-border-container .fr-btn-table-border-bg-color .fr-border-color-preview .fr-border-color-preview-indicator, .fr-table-dimensions-container .fr-btn-table-border-bg-color .fr-border-color-preview .fr-border-color-preview-indicator, .fr-table-dimensions-section .fr-btn-table-border-bg-color .fr-border-color-preview .fr-border-color-preview-indicator {
        position: absolute;
        background: red;
        width: 28px;
        height: 1px;
        top: 9px;
        left: -4px;
        transform: rotate(-45deg);
        transform-origin: center; }

.fr-table-style > button {
  width: 100%; }

.fr-table-style .fr-dropdown-wrapper {
  width: 200px; }

.fr-table-alignment-container {
  height: 33px;
  border: 1px solid #CCCCCC;
  margin-top: 10px;
  border-radius: 2px;
  min-width: 130px; }
  .fr-table-alignment-container button {
    height: 30px;
    width: 36px;
    padding: 2px 2px 2px 5px;
    border: none;
    background: transparent;
    margin: 2px;
    cursor: pointer; }
