/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-find-replace-layer .fr-header {
  padding: 15px; }
.fr-find-replace-layer .fr-body {
  padding: 0 15px 15px; }
.fr-find-replace-layer .fr-drag-handle {
  cursor: move; }
.fr-find-replace-layer h3 {
  margin: 0;
  font-size: 16px;
  text-align: left;
  font-weight: bold; }
.fr-find-replace-layer .fr-body .fr-input-line input.fr-disabled {
  background-color: #f5f5f5;
  color: #a9a9a9;
  border: 1px solid #d1d1d1;
  cursor: not-allowed; }
.fr-find-replace-layer .fr-body .fr-input-line input.fr-findText::placeholder,
.fr-find-replace-layer .fr-body .fr-input-line input.fr-replaceText::placeholder {
  color: #a9a9a9; }
.fr-find-replace-layer .fr-body .fr-input-line.fr-find-field {
  width: 227px;
  padding-bottom: 5px; }
.fr-find-replace-layer .fr-body .fr-input-line.fr-replace-field {
  top: -8px;
  padding-bottom: 0px; }
.fr-find-replace-layer .fr-body .fr-label-disabled {
  background-color: #f5f5f5; }
.fr-find-replace-layer .fr-body .fr-close-btn {
  position: absolute;
  top: 2px;
  right: 10px;
  font-size: 25px;
  background: none;
  border: none;
  cursor: pointer;
  color: #333333; }
.fr-find-replace-layer .fr-body .fr-close-btn:hover {
  color: #CCCCCC; }
.fr-find-replace-layer .fr-body .fr-toggle-advanced-options {
  display: inline-flex;
  align-items: center;
  justify-content: space-between;
  padding: 10px 0px;
  background-color: #f5f5f5;
  border-radius: 4px;
  cursor: pointer;
  font-weight: bold;
  transition: background-color 0.3s ease;
  width: 100%;
  background: none;
  color: #333333; }
.fr-find-replace-layer .fr-body input {
  padding: 8px;
  font-size: 14px;
  border: 1px solid #CCCCCC;
  border-radius: 4px;
  margin-left: 0px; }
.fr-find-replace-layer .fr-body .fr-input-container {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%;
  /* Ensures proper layout for container */ }
.fr-find-replace-layer .fr-body .fr-arrow-buttons {
  display: flex;
  flex-direction: row;
  gap: 5px;
  margin-left: 10px;
  /* Add margin to separate from input field */
  margin-top: 10px;
  /* Align with input field */ }
  .fr-find-replace-layer .fr-body .fr-arrow-buttons button {
    border: none;
    background: none;
    cursor: pointer;
    padding: 2px 4px;
    margin-bottom: 12px;
    font-size: 12px; }
  .fr-find-replace-layer .fr-body .fr-arrow-buttons .fr-disabled {
    pointer-events: none;
    cursor: not-allowed;
    color: #a9a9a9; }
.fr-find-replace-layer .fr-body .fr-button-group {
  display: flex;
  gap: 10px;
  justify-content: flex-end;
  margin-top: 10px; }
  .fr-find-replace-layer .fr-body .fr-button-group button.fr-find-btn {
    background-color: #FFF;
    color: #0098f7;
    margin-top: 10px;
    border: 1px solid #0098f7; }
  .fr-find-replace-layer .fr-body .fr-button-group button.fr-replace-btn {
    background-color: #FFF;
    color: #0098f7;
    font-size: 14px;
    margin-top: 10px; }
  .fr-find-replace-layer .fr-body .fr-button-group button.fr-replace-btn.fr-disabled {
    pointer-events: none;
    cursor: not-allowed;
    color: #a9a9a9; }
  .fr-find-replace-layer .fr-body .fr-button-group button.fr-replace-all-btn {
    background-color: #FFF;
    color: #0098f7;
    font-size: 14px;
    margin-top: 10px; }
  .fr-find-replace-layer .fr-body .fr-button-group button.fr-replace-all-btn.fr-disabled {
    pointer-events: none;
    cursor: not-allowed;
    color: #a9a9a9; }
.fr-find-replace-layer .fr-body button {
  padding: 8px 12px;
  font-size: 14px;
  border: none;
  border-radius: 4px;
  cursor: pointer; }
.fr-find-replace-layer .fr-body .fr-input-container {
  position: relative;
  display: flex;
  align-items: center; }
.fr-find-replace-layer .fr-body .fr-replaceText {
  width: 77%; }
.fr-find-replace-layer .fr-body .fr-findText {
  position: relative;
  padding-right: 40px;
  /* Create space for the count indicator */
  font-size: 14px;
  border: 1px solid #CCCCCC;
  border-radius: 4px; }
.fr-find-replace-layer .fr-body .fr-findText:focus {
  border: 2px solid #0098f7; }
.fr-find-replace-layer .fr-body .fr-find-error {
  color: #f70000;
  font-size: 12px;
  display: none;
  max-width: 300px;
  overflow-wrap: break-word; }
.fr-find-replace-layer .fr-body .fr-findText.error {
  border-color: #f70000; }
.fr-find-replace-layer .fr-body .fr-count-indicator {
  position: absolute;
  right: 80px;
  top: 57%;
  /* Center vertically */
  transform: translateY(-50%);
  color: #CCCCCC;
  font-size: 12px;
  pointer-events: none;
  visibility: hidden;
  /* Hidden by default */
  z-index: 10; }
.fr-find-replace-layer .fr-body .fr-toggle-advanced-options .arrow {
  font-size: 15px;
  transition: transform 0.3s ease;
  margin-right: 10px;
  font-size: 14px;
  margin-right: 4px;
  margin-top: 2px;
  font-weight: 100; }
.fr-find-replace-layer .fr-body .fr-advanced-options-panel {
  border-radius: 4px; }
  .fr-find-replace-layer .fr-body .fr-advanced-options-panel .fr-checkbox-group {
    display: flex;
    flex-direction: column;
    gap: 8px; }
    .fr-find-replace-layer .fr-body .fr-advanced-options-panel .fr-checkbox-group .fr-checkbox-row {
      display: flex;
      align-items: center;
      gap: 6px;
      font-size: 14px; }
      .fr-find-replace-layer .fr-body .fr-advanced-options-panel .fr-checkbox-group .fr-checkbox-row input[type="checkbox"]:focus-visible {
        outline: 2px solid #0098f7;
        outline-offset: 2px; }
.fr-find-replace-layer .fr-body .fr-toggle-btn {
  width: 40px;
  height: 20px;
  background-color: #CCCCCC;
  border-radius: 10px;
  position: relative;
  cursor: pointer;
  margin-right: 10px;
  display: inline-block;
  vertical-align: middle; }
.fr-find-replace-layer .fr-body .fr-arrow {
  margin-right: 5px;
  font-size: 12px;
  margin-top: 1px;
  position: absolute;
  right: 15px; }
.fr-find-replace-layer .fr-body .fr-disabled svg.fr-arrow-button {
  fill: #a9a9a9; }
.fr-find-replace-layer .fr-body .fr-arrow-button {
  width: 12px;
  height: 12px; }
.fr-find-replace-layer .fr-body .fr-btn-active-popup {
  background: #d6d6d6; }

.fr-find-replace-highlight {
  background-color: #ffff00; }

.fr-find-replace-current-highlight {
  background-color: #ffa500; }
