/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal {
  text-align: left;
  padding: 20px 20px 10px; }
  .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table {
    border-collapse: collapse;
    font-size: 14px;
    line-height: 1.5;
    width: 100%; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table + table {
      margin-top: 20px; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tr {
      border: 0; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table th {
      text-align: left; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table th, .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table td {
      padding: 6px 0 4px; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody tr {
      border-bottom: solid 1px #ebebeb; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody td:first-child {
      width: 60%;
      color: #646464; }
    .fr-modal .fr-modal-wrapper .fr-modal-body .fr-help-modal table tbody td:nth-child(n+2) {
      letter-spacing: 0.5px; }
