/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-popup .fr-icon.fr-fa-icon {
  width: 18px;
  padding: 8px;
  margin: 6px;
  font-size: 16px; }
@supports not (-ms-high-contrast: none) {
  .fr-popup .fr-icon-container.fr-fa-container {
    grid-template-columns: repeat(auto-fill, minmax(45px, 45px)); } }
@media screen and (-ms-high-contrast: active) and (min-width: 768px), (-ms-high-contrast: none) and (min-width: 768px) {
  .fr-popup .fr-icon-container.fr-fa-container {
    width: 506px; } }
