/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-quick-insert {
  position: absolute;
  z-index: 2147483639;
  white-space: nowrap;
  padding-right: 10px;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box; }
  .fr-quick-insert a.fr-floating-btn svg {
    margin: 8px;
    width: 24px;
    height: 24px; }
  .fr-quick-insert.fr-on a.fr-floating-btn svg {
    -webkit-transform: rotate(135deg);
    -moz-transform: rotate(135deg);
    -ms-transform: rotate(135deg);
    -o-transform: rotate(135deg); }
  .fr-quick-insert.fr-hidden {
    display: none; }

.fr-qi-helper {
  position: absolute;
  z-index: 3;
  padding-left: 20px;
  white-space: nowrap; }
  .fr-qi-helper a.fr-btn.fr-floating-btn {
    text-align: center;
    padding: 6px 10px 10px 10px;
    display: inline-block;
    color: #222222;
    background: #FFF;
    -webkit-opacity: 0;
    -moz-opacity: 0;
    opacity: 0;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    -webkit-transform: scale(0);
    -moz-transform: scale(0);
    -ms-transform: scale(0);
    -o-transform: scale(0); }
    .fr-qi-helper a.fr-btn.fr-floating-btn svg {
      fill: #222222; }
    .fr-qi-helper a.fr-btn.fr-floating-btn.fr-size-1 {
      -webkit-opacity: 1;
      -moz-opacity: 1;
      opacity: 1;
      -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
      -webkit-transform: scale(1);
      -moz-transform: scale(1);
      -ms-transform: scale(1);
      -o-transform: scale(1); }
