/*!
 * froala_editor v4.7.1 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2025 Froala Labs
 */

.fr-clearfix::after {
  clear: both;
  display: block;
  content: "";
  height: 0; }

.fr-hide-by-clipping {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.fr-line-breaker {
  cursor: text;
  border-top: 1px solid #0098f7;
  position: fixed;
  z-index: 2;
  display: none; }
  .fr-line-breaker.fr-visible {
    display: block; }
  .fr-line-breaker a.fr-floating-btn {
    position: absolute;
    left: calc(50% - (40px / 2));
    top: -20px; }
    .fr-line-breaker a.fr-floating-btn svg {
      margin: 8px;
      height: 24px;
      width: 24px; }
