PLUGINS = (
    'align', 'char_counter', 'code_beautifier', 'code_view', 'colors', 'draggable', 'emoticons', 'entities', 'file',
    'font_family', 'font_size', 'fullscreen', 'help', 'image', 'image_manager', 'inline_style', 'line_breaker', 'link', 'lists',
    'paragraph_format', 'paragraph_style', 'print', 'quick_insert', 'quote', 'save', 'special_characters', 'table', 'url',
    'video', 'word_paste'
)

PLUGINS_WITH_CSS = (
    'char_counter', 'code_view', 'colors', 'draggable', 'emoticons', 'file', 'fullscreen', 'help', 'image', 'image_manager',
    'line_breaker', 'quick_insert', 'special_characters', 'table', 'video', 'markdown', 'filestack'
)

THIRD_PARTY = (
    # 'image_aviary', 'spell_checker'
)

THIRD_PARTY_WITH_CSS = (
    'spell_checker'
)
